@@ -14,7 +14,6 @@ import time
 import yaml
 import csv
 import itertools
-import shutil
 from collections import OrderedDict, Callable
 import pkg_resources
 # mine
@@ -65,18 +64,6 @@ class DefaultOrderedDict(OrderedDict):
                                                OrderedDict.__repr__(self))
 
 
-def create_adjusted_model_for_percentages(model_src, model_use):
-    """Replace logreg layer by sigmoid to get probabilities."""
-    # Copy model file
-    shutil.copyfile(model_src, model_use)
-    # Adjust model file
-    with open(model_src) as f:
-        content = f.read()
-    content = content.replace("logreg", "sigmoid")
-    with open(model_use, "w") as f:
-        f.write(content)
-
-
 def get_test_results(model_folder, basename, test_file):
     model_src = utils.get_latest_model(model_folder, basename)
     if model_src is None:
@@ -85,7 +72,7 @@ def get_test_results(model_folder, basename, test_file):
                       model_folder)
     else:
         model_use = "tmp.json"  # TODO write elsewhere in a temporary folder
-        create_adjusted_model_for_percentages(model_src, model_use)
+        utils.create_adjusted_model_for_percentages(model_src, model_use)
 
         # Start evaluation
         PROJECT_ROOT = utils.get_project_root()
